/**
 * @file Defines `Cmd`s as streams of asynchronous operations which can not fail and that can optionally carry a message.
 *
 * See the [Platform.Cmd](https://package.elm-lang.org/packages/elm/core/latest/Platform-Cmd) Elm package.
 */
import { Option } from 'fp-ts/lib/Option';
import { Task } from 'fp-ts/lib/Task';
import { Observable } from 'rxjs';
/**
 * @since 0.5.0
 */
export interface Cmd<Msg> extends Observable<Task<Option<Msg>>> {
}
/**
 * Creates a new `Cmd` that carries the provided `Msg`.
 * @since 0.5.0
 */
export declare function of<Msg>(m: Msg): Cmd<Msg>;
/**
 * Maps the carried `Msg` of a `Cmd` into another `Msg`.
 * @since 0.5.0
 */
export declare function map<A, Msg>(f: (a: A) => Msg): (cmd: Cmd<A>) => Cmd<Msg>;
/**
 * Batches the execution of a list of commands.
 * @since 0.5.0
 */
export declare function batch<Msg>(arr: Array<Cmd<Msg>>): Cmd<Msg>;
/**
 * A `none` command is an empty stream.
 * @since 0.5.0
 */
export declare const none: Cmd<never>;
