"use strict";
/**
 * @file Defines `Cmd`s as streams of asynchronous operations which can not fail and that can optionally carry a message.
 *
 * See the [Platform.Cmd](https://package.elm-lang.org/packages/elm/core/latest/Platform-Cmd) Elm package.
 */
Object.defineProperty(exports, "__esModule", { value: true });
var Option_1 = require("fp-ts/lib/Option");
var Task_1 = require("fp-ts/lib/Task");
var rxjs_1 = require("rxjs");
var operators_1 = require("rxjs/operators");
/**
 * Creates a new `Cmd` that carries the provided `Msg`.
 * @since 0.5.0
 */
function of(m) {
    return rxjs_1.of(Task_1.task.of(Option_1.some(m)));
}
exports.of = of;
/**
 * Maps the carried `Msg` of a `Cmd` into another `Msg`.
 * @since 0.5.0
 */
function map(f) {
    return function (cmd) { return cmd.pipe(operators_1.map(function (t) { return Task_1.task.map(t, function (o) { return Option_1.option.map(o, f); }); })); };
}
exports.map = map;
/**
 * Batches the execution of a list of commands.
 * @since 0.5.0
 */
function batch(arr) {
    return rxjs_1.merge.apply(void 0, arr);
}
exports.batch = batch;
/**
 * A `none` command is an empty stream.
 * @since 0.5.0
 */
exports.none = rxjs_1.EMPTY;
//# sourceMappingURL=Cmd.js.map