"use strict";
/**
 * @file Debug via standard browser's `console`
 */
Object.defineProperty(exports, "__esModule", { value: true });
var Option_1 = require("fp-ts/lib/Option");
var pipeable_1 = require("fp-ts/lib/pipeable");
/**
 * **[UNSAFE]** Simple debugger that uses the standard browser's `console`
 * @since 0.5.0
 */
function consoleDebugger() {
    return function () { return function (data) {
        var action = data[0], model = data[1];
        console.group('%cELM-TS', 'background-color: green; color: black');
        // --- Action
        if (action.type === 'INIT') {
            console.log('[INIT]');
        }
        if (action.type === 'MESSAGE') {
            var showType = Option_1.getOrElse(function () { return ''; })(getMsgType(action));
            console.groupCollapsed("[MESSAGE] %c" + showType, 'font-weight: bold');
            console.dir(action.payload);
            console.groupEnd();
        }
        // --- Model
        console.groupCollapsed('[MODEL]');
        console.dir(model);
        console.groupEnd();
        console.groupEnd();
    }; };
}
exports.consoleDebugger = consoleDebugger;
/**
 * Tries to extract the "type" of a `Message` reading the value of the [_discriminant_ property](http://www.typescriptlang.org/docs/handbook/advanced-types.html#discriminated-unions) (iterating through a list of commonly used names - e.g. "tag", "type", "kind" etc.)
 * @since 0.5.0
 */
function getMsgType(m) {
    var payload = m.payload;
    return pipeable_1.pipe(Option_1.fromNullable(payload['tag']), Option_1.alt(function () { return Option_1.fromNullable(payload['_tag']); }), Option_1.alt(function () { return Option_1.fromNullable(payload['type']); }), Option_1.alt(function () { return Option_1.fromNullable(payload['_type']); }), Option_1.alt(function () { return Option_1.fromNullable(payload['kind']); }), Option_1.alt(function () { return Option_1.fromNullable(payload['_kind']); }));
}
//# sourceMappingURL=console.js.map