/**
 * @file Defines a `Decoder`, namely a function that receives an `unknown` value and tries to decodes it in an `A` value.
 *
 * It returns an `Either` with a `string` as `Left` when decoding fails or an `A` as `Right` when decoding succeeds.
 */
import { Alternative1 } from 'fp-ts/lib/Alternative';
import { Monad1 } from 'fp-ts/lib/Monad';
import * as RE from 'fp-ts/lib/ReaderEither';
import ReaderEither = RE.ReaderEither;
declare module 'fp-ts/lib/HKT' {
    interface URItoKind<A> {
        Decoder: Decoder<A>;
    }
}
/**
 * @since 0.5.0
 */
export declare const URI = "Decoder";
/**
 * @since 0.5.0
 */
export declare type URI = typeof URI;
/**
 * @since 0.5.0
 */
export interface Decoder<A> extends ReaderEither<unknown, string, A> {
}
/**
 * @since 0.5.0
 */
export declare const left: <A = never>(e: string) => Decoder<A>;
/**
 * @since 0.5.0
 */
export declare const right: <A>(a: A) => Decoder<A>;
/**
 * @since 0.5.0
 */
export declare const orElse: <A>(f: (e: string) => Decoder<A>) => (ma: Decoder<A>) => Decoder<A>;
/**
 * @since 0.5.0
 */
export declare const decoder: Monad1<URI> & Alternative1<URI>;
declare const alt: <A>(that: () => Decoder<A>) => (fa: Decoder<A>) => Decoder<A>, ap: <A>(fa: Decoder<A>) => <B>(fab: Decoder<(a: A) => B>) => Decoder<B>, apFirst: <B>(fb: Decoder<B>) => <A>(fa: Decoder<A>) => Decoder<A>, apSecond: <B>(fb: Decoder<B>) => <A>(fa: Decoder<A>) => Decoder<B>, chain: <A, B>(f: (a: A) => Decoder<B>) => (ma: Decoder<A>) => Decoder<B>, chainFirst: <A, B>(f: (a: A) => Decoder<B>) => (ma: Decoder<A>) => Decoder<A>, flatten: <A>(mma: Decoder<Decoder<A>>) => Decoder<A>, map: <A, B>(f: (a: A) => B) => (fa: Decoder<A>) => Decoder<B>;
export { 
/**
 * @since 0.5.0
 */
alt, 
/**
 * @since 0.5.0
 */
ap, 
/**
 * @since 0.5.0
 */
apFirst, 
/**
 * @since 0.5.0
 */
apSecond, 
/**
 * @since 0.5.0
 */
chain, 
/**
 * @since 0.5.0
 */
chainFirst, 
/**
 * @since 0.5.0
 */
flatten, 
/**
 * @since 0.5.0
 */
map };
