"use strict";
/**
 * @file Makes http calls to remote resources as `Cmd`s.
 *
 * See [Http](https://package.elm-lang.org/packages/elm/http/latest/Http) Elm package.
 */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var E = require("fp-ts/lib/Either");
var O = require("fp-ts/lib/Option");
var T = require("fp-ts/lib/Task");
var function_1 = require("fp-ts/lib/function");
var pipeable_1 = require("fp-ts/lib/pipeable");
var rxjs_1 = require("rxjs");
var ajax_1 = require("rxjs/ajax");
var operators_1 = require("rxjs/operators");
/**
 * @since 0.5.0
 */
function toTask(req) {
    return function () { return xhr(req).toPromise(); };
}
exports.toTask = toTask;
/**
 * Executes as `Cmd` the provided call to remote resource, mapping result to a `Msg`.
 * @since 0.5.0
 */
function send(f) {
    return function (req) { return xhr(req).pipe(operators_1.map(function (result) { return T.of(O.some(f(result))); })); };
}
exports.send = send;
/**
 * @since 0.5.0
 */
function get(url, decoder) {
    return {
        method: 'GET',
        headers: {},
        url: url,
        body: undefined,
        expect: decoder,
        timeout: O.none,
        withCredentials: false
    };
}
exports.get = get;
/**
 * @since 0.5.0
 */
function post(url, body, decoder) {
    return {
        method: 'POST',
        headers: {},
        url: url,
        body: body,
        expect: decoder,
        timeout: O.none,
        withCredentials: false
    };
}
exports.post = post;
// --- Helpers
function xhr(req) {
    return ajax_1.ajax(toXHRRequest(req)).pipe(operators_1.map(function_1.flow(toResponse(req), decodeWith(req.expect))), operators_1.catchError(function (e) { return rxjs_1.of(E.left(toHttpError(e))); }));
}
function toXHRRequest(req) {
    return __assign({}, req, { timeout: pipeable_1.pipe(req.timeout, O.fold(function () { return 0; }, function_1.identity)), async: true, responseType: 'json' });
}
function toResponse(req) {
    return function (resp) { return ({
        url: req.url,
        status: {
            code: resp.status,
            message: ''
        },
        headers: req.headers,
        body: resp.response
    }); };
}
function decodeWith(decoder) {
    return function (resp) {
        return pipeable_1.pipe(decoder(resp.body), E.mapLeft(function (e) { return ({
            _tag: 'BadPayload',
            value: e,
            response: resp
        }); }));
    };
}
function toHttpError(e) {
    if (e instanceof ajax_1.AjaxTimeoutError) {
        return { _tag: 'Timeout' };
    }
    // RxJS ajax method can throw errors of different types (not just `AjaxError`).
    // These controls seem to cover every case.
    if (e instanceof ajax_1.AjaxError && e.status === 404) {
        return { _tag: 'BadUrl', value: e.request.url };
    }
    if (e instanceof ajax_1.AjaxError && e.status !== 0) {
        return { _tag: 'BadStatus', response: e.response };
    }
    // Parsing json in response could throw a `SyntaxError`.
    if ('constructor' in e && 'name' in e.constructor && e.constructor.name === 'SyntaxError') {
        return { _tag: 'BadPayload', value: e.message, response: e.response };
    }
    return { _tag: 'NetworkError', value: e.message };
}
//# sourceMappingURL=Http.js.map