/**
 * @file A specialization of `Program` that handles application navigation via location's hash.
 *
 * It uses [`history`](https://github.com/ReactTraining/history) package
 */
import * as H from 'history';
import { Cmd } from './Cmd';
import * as html from './Html';
import { Sub } from './Sub';
/**
 * @since 0.5.0
 */
export declare type Location = H.Location;
/**
 * Generates a `Cmd` that adds a new location to the history's list.
 * @since 0.5.0
 */
export declare function push<Msg>(url: string): Cmd<Msg>;
/**
 * Returns a `Program` specialized for `Navigation`.
 *
 * The `Program` is a `Html.Program` but it needs a `locationToMsg()` function which converts location changes to messages.
 *
 * Underneath it consumes `location$` stream (applying `locationToMsg()` on its values).
 * @since 0.5.0
 */
export declare function program<Model, Msg, Dom>(locationToMessage: (location: Location) => Msg, init: (location: Location) => [Model, Cmd<Msg>], update: (msg: Msg, model: Model) => [Model, Cmd<Msg>], view: (model: Model) => html.Html<Dom, Msg>, subscriptions?: (model: Model) => Sub<Msg>): html.Program<Model, Msg, Dom>;
/**
 * Same as `program()` but with `Flags` that can be passed when the `Program` is created in order to manage initial values.
 * @since 0.5.0
 */
export declare function programWithFlags<Flags, Model, Msg, Dom>(locationToMessage: (location: Location) => Msg, init: (flags: Flags) => (location: Location) => [Model, Cmd<Msg>], update: (msg: Msg, model: Model) => [Model, Cmd<Msg>], view: (model: Model) => html.Html<Dom, Msg>, subscriptions?: (model: Model) => Sub<Msg>): (flags: Flags) => html.Program<Model, Msg, Dom>;
