/**
 * @file A specialization of `Html` that uses `React` as renderer.
 */
import { ReactElement } from 'react';
import { Observable } from 'rxjs';
import { Cmd } from './Cmd';
import * as html from './Html';
import { Sub } from './Sub';
/**
 * `Dom` is a `ReactElement`.
 * @since 0.5.0
 */
export interface Dom extends ReactElement<any> {
}
/**
 * `Html` has `Dom` type constrained to the specialized version for `React`.
 * @since 0.5.0
 */
export interface Html<Msg> extends html.Html<Dom, Msg> {
}
/**
 * @since 0.5.0
 */
export interface Program<Model, Msg> extends html.Program<Model, Msg, Dom> {
}
/**
 * `map()` is `Html.map()` with `Html` type constrained to the specialized version for `React`.
 * @since 0.5.0
 */
export declare function map<A, Msg>(f: (a: A) => Msg): (ha: Html<A>) => Html<Msg>;
/**
 * `program()` is `Html.program()` with `Html` type constrained to the specialized version for `React`.
 * @since 0.5.0
 */
export declare function program<Model, Msg>(init: [Model, Cmd<Msg>], update: (msg: Msg, model: Model) => [Model, Cmd<Msg>], view: (model: Model) => html.Html<Dom, Msg>, subscriptions?: (model: Model) => Sub<Msg>): Program<Model, Msg>;
/**
 * Same as `program()` but with `Flags` that can be passed when the `Program` is created in order to manage initial values.
 * @since 0.5.0
 */
export declare function programWithFlags<Flags, Model, Msg>(init: (flags: Flags) => [Model, Cmd<Msg>], update: (msg: Msg, model: Model) => [Model, Cmd<Msg>], view: (model: Model) => html.Html<Dom, Msg>, subscriptions?: (model: Model) => Sub<Msg>): (flags: Flags) => Program<Model, Msg>;
/**
 * `run()` is `Html.run()` with `dom` type constrained to the specialized version for `React`.
 * @since 0.5.0
 */
export declare function run<Model, Msg>(program: Program<Model, Msg>, renderer: html.Renderer<Dom>): Observable<Model>;
