/**
 * @file Handles the execution of asynchronous effectful operations.
 *
 * See the [Task](https://package.elm-lang.org/packages/elm/core/latest/Task) Elm package.
 */
import { Either } from 'fp-ts/lib/Either';
import { Task } from 'fp-ts/lib/Task';
import { Cmd } from './Cmd';
/**
 * Executes a `Task` as a `Cmd` mapping the result to a `Msg`.
 * @since 0.5.0
 */
export declare function perform<A, Msg>(f: (a: A) => Msg): (t: Task<A>) => Cmd<Msg>;
/**
 * Executes a `Task` that can fail as a `Cmd` mapping the result (`Either`) to a `Msg`.
 * @since 0.5.0
 */
export declare function attempt<E, A, Msg>(f: (e: Either<E, A>) => Msg): (task: Task<Either<E, A>>) => Cmd<Msg>;
