/**
 * @file Defines `Cmd`s as streams of asynchronous operations which can not fail and that can optionally carry a message.
 *
 * See the [Platform.Cmd](https://package.elm-lang.org/packages/elm/core/latest/Platform-Cmd) Elm package.
 */
import { option, some } from 'fp-ts/lib/Option';
import { task } from 'fp-ts/lib/Task';
import { EMPTY, merge, of as RxOf } from 'rxjs';
import { map as RxMap } from 'rxjs/operators';
/**
 * Creates a new `Cmd` that carries the provided `Msg`.
 * @since 0.5.0
 */
export function of(m) {
    return RxOf(task.of(some(m)));
}
/**
 * Maps the carried `Msg` of a `Cmd` into another `Msg`.
 * @since 0.5.0
 */
export function map(f) {
    return cmd => cmd.pipe(RxMap(t => task.map(t, o => option.map(o, f))));
}
/**
 * Batches the execution of a list of commands.
 * @since 0.5.0
 */
export function batch(arr) {
    return merge(...arr);
}
/**
 * A `none` command is an empty stream.
 * @since 0.5.0
 */
export const none = EMPTY;
//# sourceMappingURL=Cmd.js.map