/**
 * @file Defines a `Decoder`, namely a function that receives an `unknown` value and tries to decodes it in an `A` value.
 *
 * It returns an `Either` with a `string` as `Left` when decoding fails or an `A` as `Right` when decoding succeeds.
 */
import * as E from 'fp-ts/lib/Either';
import * as RE from 'fp-ts/lib/ReaderEither';
import { pipeable } from 'fp-ts/lib/pipeable';
/**
 * @since 0.5.0
 */
export const URI = 'Decoder';
/**
 * @since 0.5.0
 */
export const left = RE.left;
/**
 * @since 0.5.0
 */
export const right = RE.readerEither.of;
/**
 * @since 0.5.0
 */
export const orElse = RE.orElse;
/**
 * @since 0.5.0
 */
export const decoder = {
    URI,
    map: RE.readerEither.map,
    of: right,
    ap: RE.readerEither.ap,
    chain: RE.readerEither.chain,
    alt: RE.readerEither.alt,
    zero: () => () => E.left('zero')
};
const { alt, ap, apFirst, apSecond, chain, chainFirst, flatten, map } = pipeable(decoder);
export { 
/**
 * @since 0.5.0
 */
alt, 
/**
 * @since 0.5.0
 */
ap, 
/**
 * @since 0.5.0
 */
apFirst, 
/**
 * @since 0.5.0
 */
apSecond, 
/**
 * @since 0.5.0
 */
chain, 
/**
 * @since 0.5.0
 */
chainFirst, 
/**
 * @since 0.5.0
 */
flatten, 
/**
 * @since 0.5.0
 */
map };
//# sourceMappingURL=Decode.js.map