/**
 * @file A specialization of `Html` that uses `React` as renderer.
 */
import * as html from './Html';
/**
 * `map()` is `Html.map()` with `Html` type constrained to the specialized version for `React`.
 * @since 0.5.0
 */
export function map(f) {
    return html.map(f);
}
/**
 * `program()` is `Html.program()` with `Html` type constrained to the specialized version for `React`.
 * @since 0.5.0
 */
export function program(init, update, view, subscriptions) {
    return html.program(init, update, view, subscriptions);
}
/**
 * Same as `program()` but with `Flags` that can be passed when the `Program` is created in order to manage initial values.
 * @since 0.5.0
 */
export function programWithFlags(init, update, view, subscriptions) {
    return flags => program(init(flags), update, view, subscriptions);
}
/**
 * `run()` is `Html.run()` with `dom` type constrained to the specialized version for `React`.
 * @since 0.5.0
 */
export function run(program, renderer) {
    return html.run(program, renderer);
}
//# sourceMappingURL=React.js.map