/**
 * @file Handles the execution of asynchronous effectful operations.
 *
 * See the [Task](https://package.elm-lang.org/packages/elm/core/latest/Task) Elm package.
 */
import { some } from 'fp-ts/lib/Option';
import { task } from 'fp-ts/lib/Task';
import { of } from 'rxjs';
/**
 * Executes a `Task` as a `Cmd` mapping the result to a `Msg`.
 * @since 0.5.0
 */
export function perform(f) {
    return t => of(task.map(t, a => some(f(a))));
}
/**
 * Executes a `Task` that can fail as a `Cmd` mapping the result (`Either`) to a `Msg`.
 * @since 0.5.0
 */
export function attempt(f) {
    return perform(f);
}
//# sourceMappingURL=Task.js.map